@@ -29,7 +29,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <unique/uniqueapp.h>
 
 #include "user_share-private.h"
 
@@ -439,7 +438,11 @@ help_button_clicked (GtkButton *button, GtkWidget *window)
 {
 	GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	if (gtk_show_uri_on_window (GTK_WINDOW (window), "help:mate-user-share", gtk_get_current_event_time (), &error) == FALSE) {
+#else
 	if (gtk_show_uri (gtk_widget_get_screen (window), "help:mate-user-share", gtk_get_current_event_time (), &error) == FALSE) {
+#endif
 		GtkWidget *dialog;
 
 		dialog = error_dialog (_("Could not display the help contents."), error->message, GTK_WINDOW (window));
@@ -451,20 +454,8 @@ help_button_clicked (GtkButton *button, GtkWidget *window)
 	}
 }
 
-static UniqueResponse
-message_received_cb (UniqueApp         *app,
-		     int                command,
-		     UniqueMessageData *message_data,
-		     guint              time_,
-		     gpointer           user_data)
-{
-  gtk_window_present (GTK_WINDOW (user_data));
-
-  return UNIQUE_RESPONSE_OK;
-}
-
-int
-main (int argc, char *argv[])
+static GtkWidget *
+create_window (void)
 {
     GError *error = NULL;
     GSettings *settings;
@@ -483,20 +474,6 @@ main (int argc, char *argv[])
     GtkListStore *store;
     GtkCellRenderer *cell;
     GtkTreeIter iter;
-    UniqueApp *app;
-    
-    bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
-    
-    gtk_init (&argc, &argv);
-
-    app = unique_app_new ("org.mate.user-share.properties", NULL);
-    if (unique_app_is_running (app)) {
-      gdk_notify_startup_complete ();
-      unique_app_send_message (app, UNIQUE_ACTIVATE, NULL);
-      return 0;
-    }
 
     builder = gtk_builder_new ();
     gtk_builder_add_from_file (builder, DATADIR"file-share-properties.ui", &error);
@@ -509,14 +486,10 @@ main (int argc, char *argv[])
       gtk_widget_destroy (dialog);
 
       g_error_free (error);
-      return 1;
+      return NULL;
     }
 
     window = GTK_WIDGET (gtk_builder_get_object (builder, "user_share_dialog"));
-    g_signal_connect (G_OBJECT (window), "delete_event",
-		      G_CALLBACK (gtk_main_quit), NULL);
-    g_signal_connect (app, "message-received",
-		      G_CALLBACK (message_received_cb), window);
 
     settings = g_settings_new (GSETTINGS_SCHEMA);
 
@@ -606,8 +579,8 @@ main (int argc, char *argv[])
     		      "toggled", G_CALLBACK (notify_received_obexpush_check_toggled), NULL);
 #endif /* HAVE_BLUETOOTH */
 
-    g_signal_connect (GTK_WIDGET (gtk_builder_get_object (builder, "close_button")),
-		      "clicked", G_CALLBACK (gtk_main_quit), NULL);
+    g_signal_connect_swapped (GTK_WIDGET (gtk_builder_get_object (builder, "close_button")),
+                              "clicked", G_CALLBACK (gtk_widget_destroy), window);
     g_signal_connect (GTK_WIDGET (gtk_builder_get_object (builder, "help_button")),
 		      "clicked", G_CALLBACK (help_button_clicked),
 		      gtk_builder_get_object (builder, "user_share_dialog"));
@@ -641,9 +614,43 @@ main (int argc, char *argv[])
 
     update_ui ();
 
-    gtk_widget_show (GTK_WIDGET (gtk_builder_get_object (builder, "user_share_dialog")));
-    
-    gtk_main ();
+    return window;
+}
 
-    return 0;
+static void
+activate (GtkApplication *app)
+{
+    GList *list;
+    GtkWidget *window;
+
+    list = gtk_application_get_windows (app);
+
+    if (list) {
+        gtk_window_present (GTK_WINDOW (list->data));
+    } else {
+        window = create_window ();
+        gtk_window_set_application (GTK_WINDOW (window), app);
+        gtk_widget_show (window);
+    }
+}
+
+int
+main (int argc, char *argv[])
+{
+    GtkApplication *app;
+    gint status;
+
+    bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
+
+    app = gtk_application_new ("org.mate.user-share.properties",
+                               G_APPLICATION_FLAGS_NONE);
+    g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
+
+    status = g_application_run (G_APPLICATION (app), argc, argv);
+
+    g_object_unref (app);
+
+    return status;
 }
